# vim: set sw=4 ts=4 et:

# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org

Name:           smplayer
Version:        0.8.5
Release:        1.6
License:        GPL-2.0+
Summary:        Complete Frontend for MPlayer
Url:            http://smplayer.sourceforge.net/
Group:          Productivity/Multimedia/Video/Players

Source:         http://prdownloads.sourceforge.net/smplayer/smplayer-%{version}.tar.bz2
Patch1:         smplayer-makeflags.patch
Patch2:         smplayer-disable-debug.patch
Patch3:         smplayer-fix_logging_format.patch
Patch4:         smplayer-default_ao.patch
Patch8:         smplayer-simple-resize.patch
# FIX-UPSTREAM to play network shared video correctly: #PM-48
Patch9:         smplayer-add_kde_protocols_to_desktop_file.patch

BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libkde4-devel
BuildRequires:  libqt4-devel >= 4.2.0
BuildRequires:  libstdc++-devel
BuildRequires:  make
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/build-%{name}-%{version}
# requires at least this version for closed caption channel support:
Requires:       MPlayer >= 1.0rc4_r32607
Recommends:     smplayer-skins
Suggests:       smplayer-themes

%description
SMPlayer intends to be a complete front-end for MPlayer, from basic features
like playing videos, DVDs, and VCDs to more advanced features like support for
MPlayer filters and more.

One of the most interesting features of SMPlayer:it remembers the settings of
all files you play. So you start to watch a movie but you have to leave...
don't worry, when you open that movie again it will resume at the same point
you left it, and with the same settings: audio track, subtitles, volume...

%lang_package
%prep
%setup -q -n "smplayer-%{version}"
%patch1
%patch2
%patch3
%patch4
%patch9
%__perl -n -e 'print $1,"\n" if /^\+{3}\s+(.+?)\s+/' < "%{PATCH4}" | while read f; do
%if 0%{?suse_version} >= 1210
    %__sed -i 's/@@DEFAULT@@/pulse/g' "$f"
%else
    %__sed -i 's/@@DEFAULT@@/alsa/g' "$f"
%endif
done
#'

pushd src
#% patch5
#% patch6
#% patch7
%patch8
popd

# fix CRLF in .txt files:
%__sed -i 's/\r$//' *.txt

find . -type f -name '*.pro' | while read f; do
cat <<EOF >>"$f"

QMAKE_CFLAGS = %{optflags}
QMAKE_CXXFLAGS = %{optflags}

EOF
done

%build
%__make \
    MAKEFLAGS="%{?_smp_flags}" \
    CONF_PREFIX="" \
    PREFIX="%{_prefix}" \
    KDE_PREFIX="%{_prefix}" \
    DOC_PATH="%{_docdir}/%{name}" \
    KDE_SUPPORT=1 \
    KDE_INCLUDE_PATH="/usr/include" \
    KDE_LIB_PATH="{%_libdir}"

%install
%__make \
    MAKEFLAGS="" \
    CONF_PREFIX="%{buildroot}" \
    PREFIX="%{buildroot}%{_prefix}" \
    KDE_PREFIX="%{buildroot}%{_prefix}" \
    DOC_PATH="%{buildroot}%{_docdir}/%{name}" \
    KDE_SUPPORT=1 \
    KDE_INCLUDE_PATH="/usr/include" \
    KDE_LIB_PATH="%{_libdir}" \
    install

%__rm -rf "%{buildroot}%{_docdir}/%{name}"

# Append Qt;KDE; categories in desktop files - fix for #PM-48
for desktop in smplayer smplayer_enqueue; do
    %suse_update_desktop_file -r "$desktop" Qt KDE AudioVideo Video Player
done

LANGFILE="$PWD/smplayer.lang"
echo -n > "$LANGFILE"
find "%{buildroot}%{_datadir}/smplayer/translations" -name '*.qm' \
| while read qm; do
    qmfile=${qm##*/}
    l=${qmfile#*_}
    l=${l%%.qm}

    [ "$l" = "en_US" ] && continue    
    echo "%lang(${l}) %{_datadir}/smplayer/translations/${qmfile}" >> "$LANGFILE"
done
%__install -d "%{buildroot}%{_docdir}/%{name}"
pushd docs
for l in *; do
    %__cp -a "$l" "%{buildroot}%{_docdir}/%{name}/${l}"

    [ "$l" = "en" ] && continue
    echo "%lang(${l}) %{_docdir}/%{name}/${l}" >> "$LANGFILE"
done
popd #docs

%__install -m0644 Changelog *.txt "%{buildroot}%{_docdir}/%{name}"/

%files
%defattr(-,root,root)
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/Changelog
%doc %{_docdir}/%{name}/*.txt
%doc %{_docdir}/%{name}/en
%{_bindir}/smplayer
%{_datadir}/applications/smplayer.desktop
%{_datadir}/applications/smplayer_enqueue.desktop
%{_datadir}/icons/*/*/apps/smplayer.*
%dir %{_datadir}/icons/hicolor/512x512
%dir %{_datadir}/icons/hicolor/512x512/apps
%dir %{_datadir}/smplayer
%config %{_datadir}/smplayer/input.conf
%dir %{_datadir}/smplayer/shortcuts
%{_datadir}/smplayer/shortcuts/*.keys
%dir %{_datadir}/smplayer/translations
%doc %{_mandir}/man1/smplayer.1%{ext_man}
%lang(en_US) %{_datadir}/smplayer/translations/smplayer_en_US.qm

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Thu May  9 2013 dap.darkness@gmail.com
- Update to 0.8.5:
  * Smplayer could find subtitles again.
  * The interface with support for skins is now the default.
  * An option to enter url(s) in the playlist has been added.
  * The options to change the size of the main window work now
    even if the autoresize is set to never.
  * Two new options for Audio -> Stereo mode: Mono and Reverse.
  * The option "Move the window when the video area is dragged" is
    now disabled by default because it has some issues.
  * The problem with mplayer2 and the -fontconfig option has been
    fixed (sort of).
  * New translation: Malay.
  * Some configuration options are changed to new defaults after
    installation to ease upgrade.
- Clean-section was removed as unneeded.
- QMAKE_CFLAGS = %%{optflags} was added to prevent a warning.
- Spec-header was fixed up.
* Sun Mar 24 2013 dap.darkness@gmail.com
- Update to 0.8.4:
  * New option to select the fps for external subtitles.
  * The video equalizer dialog has been rewritten.
  * Now smplayer checks for updates automatically.
  * Support for encoding ISO-8859-16 for subtitles.
  * New translations: Thai and Hebrew.
  * Some bugfixes.
- Switched to use download_files service.
- Service source_validator was enabled.
* Sun Dec 23 2012 fisiu@opensuse.org
- Update to 0.8.3:
  * Fix Youtube playback
  * Added skinnable interface
  * Added support for 6.1 and 7.1 sound
  * New "Privacy" section in Preferences
* Sat Oct 20 2012 pascal.bleser@opensuse.org
- Fix #PM-48: add X-KDE-Protocols to desktop file:
  https://bugs.links2linux.org/browse/PM-48
* Wed Oct 17 2012 fisiu@opensuse.org
- Fix #PM-48: remote file need to be cached before playback.
* Tue Oct  9 2012 i@margueirte.su
- update to 0.8.1
  * Fix youtube playback.
* Sat Oct  6 2012 i@margueirte.su
- fix the bug that it goes into audio player section in kickoff menu.
* Sun Apr 15 2012 pascal.bleser@opensuse.org
- update to 0.8.0:
  * find subtitles window: display first the most used languages in the filter
  combobox
  * and add "pb" for Portuguese from Brasil
  * fix the line breaks on downloaded *.sub files from opensubtitles
  * (Youtube) recognize short urls
  * display chapter names in the chapter menu
  * it's possible to change GUI without restarting
  * bug fix: remote m3u didn't open from the favorites menu or command line
  * move the blur and sharpen filters to a group, so only one can be activated
  * move the denoise and blur/sharpen options to submenus
  * Youtube quality by default is now mp4/720p
  * the default width of the floating control is now 70%%
  * toolbar editor: give a name to the widget actions (time slider and so on)
  * add gradfun to video -> filters
  * add blur and sharpen filters
  * support for drag and drop in the toolbar editor
  * Toolbar editor: if you right click on any toolbar you'll get a menu with
  options to edit the toolbars (including the control bars)
  * use QtSingleApplication instead of the old client/server code to use a
  single instance and communication with other instances
  * fix: the buttons to select the color of the subtiles in preferences ->
  subtitles may not change the background color with some styles: now the
  color is changed using a stylesheet, so it should work with all styles
  * improve detection of youtube urls
* Tue Jan 31 2012 fisiu@opensuse.org
- Update to 0.7.0:
  + Support for YouTube.
  + Support for mplayer2.
  + New favorite menu (it allows You to add favorite videos, music, streams,
    youtube videos...).
  + New translation: croatian.
* Sat Dec 31 2011 pascal.bleser@opensuse.org
- default audio codec is now pulse on >= 12.1
- properly pass optflags, including stack protector
- update to 0.6:10
  * added a vdpau configuration dialog, now it's possible to select which vdpau
    codecs to use
  * removed the option "Visualize motion vectors". It caused problems to many
    people when activated by mistake.
  * added a submenu to select the closed caption channel; requires mplayer >=
    r32607
  * added webm and vp8 to the list of extensions (for video)
  * added thd to the list of extensions (for audio)
  * added hdmov to the list of extensions (for video)
  * added f4v to the list of extensions (for video)
  * (Experimental) if using mplayer svn r31030, the audio filters (karaoke,
    extrastereo and volnorm) are changed without restarting mplayer, using the
    new slave commands af_add and af_del
  * for consistency, the playlist preferences have been moved to the playlist
    section in the main preferences dialog (and the playlist own preferences
    dialog has been deleted)
  * added the Danish translation, by Martin Schlander <mschlander@opensuse.org>
  * added the possibility to select the seeking method (absolute or relative)
    in Preferences -> Interface
  * possibility to sort the items of the playlist
* Fri Aug 26 2011 pascal.bleser@opensuse.org
- update to 0.6.9+r3615:
  * updated translations: Basque, Russian, Turkish, Galician, German,
  * now recognizes MPlayer 1.0rc4
  * added functionality to the telnet interface
  * use the mplayer command "af_cmdline equalizer" (added in mplayer 32505), to
    change the audio equalizer
* Mon Mar 21 2011 pascal.bleser@opensuse.org
- update to 0.6.9+r3599:
  * added patch smplayer-subtitle-downloader.patch (SF#3179078)
  * applied patch notagintitle.diff by WiseLord, with a minor change to restart
    playback after modifying the "Show tag info in window title" option
* Thu Jan 20 2011 pascal.bleser@opensuse.org
- fix conflict on en_US file between smplayer and smplayer-lang
- update to 0.6.9+r3597:
  * added a submenu to select the closed caption channel (requires
    mplayer >= r32607)
  * added webm and vp8 to the list of extensions (for video)
  * added thd to the list of extensions (for audio)
  * added hdmov to the list of extensions (for video)
  * added f4v to the list of extensions (for video)
  * (experimental) if using mplayer svn r31030, the audio filters
    (karaoke, extrastereo and volnorm) are changed without
    restarting mplayer, using the new slave commands af_add and
    af_del
  * for consistency, the playlist preferences have been moved to the
    playlist section in the main preferences dialog (and the
    playlist own preferences dialog has been deleted)
  * added the Danish translation, by Martin Schlander
  * added the possibility to select the seeking method (absolute or
    relative) in Preferences -> Interface
  * possibility to sort the items of the playlist
* Wed Mar  3 2010 pascal@links2linux.de
- update to 0.6.9:
  * fixed a serious bug: sometimes smplayer failed to find
    subtitles in opensubtitles.org
  * implemented the possibility to mark an A-B section, to play a
    part of the file only
  * possibility to display the video resolution and frames per
    second in the status bar
  * audio: selection of left or right channel does work now
  * improved support for vdpau
- splitted out translations into -lang subpackage
- added patch to make alsa default when no audio output backend is
  specified, even though that was removed upstream because of
  freezing issues on Ubuntu
* Sat Jul 25 2009 pascal.bleser@opensuse.org
- update to 0.6.8:
  * adds support for TV (more info in Watching_TV.txt)
  * new option to enable a global volume
  * support for vdpau
  * new option to take consecutive screenshots
  * possibility to add some of the submenus to the toolbars
  * better support for *.ts files (requires mplayer >= r29381)
  * added the Vietnamese translation
  * added the Estonian translation.
* Thu Mar 12 2009 pascal.bleser@opensuse.org
- update to 0.6.7:
  * adds experimental (and uncomplete) support for dvd menus; requires a
    mplayer build compiled with dvdnav support; please read
    %%%%{_docdir}/%%%%{name}/dvdmenus.txt to know how to enable it
  * now loading an external subtitle file doesn't require to restart the
    mplayer process (except for idx/sub subtitles)
  * playlist: when a file is added to the playlist, if it was already in the
    list, it's moved to the end of the list
  * options for mplayer: finally spaces in arguments between quotes are
    handled properly
  * added two options (in the audio and subtitle menus) to allow the user to
    enter the audio and subtitle delay (in milliseconds)
  * ASS subtitles: the outline and shadow options now accept values with
    decimals
  * ASS subtitles: possibility to change the color of the border and shadow
  * now the default value for the "correct pts" option is auto
* Fri Jan  2 2009 guru@unixtech.be
- update to 0.6.6:
  * added an option to generate a preview (thumbnails) of the video
  * added a new gui (mpcgui, a media player classic clone) developed by
    Matthias Petri
  * added some auto zoom options, to display the video without black borders
  * implemented a new (and optional) method to save the file settings; this
    method uses an ini file per each played file, it's faster than the old one
  * added a new option in Preferences->Video: add black borders on fullscreen:
    if this option is enabled, black borders will be added to the image in
    fullscreen mode; this allows subtitles to be displayed on the black
    borders
  * increased the resolution of the seekbar; allows a more accurate seeking
  * added 3 modes for the stay on top option: always, never and while playing
  * added a history to the open URL dialog
  * added new action to cycle through all aspect ratios, assigned by default
    to key "A"
  * it's possible to run some specified actions every time a file is loaded
  * possibility to set up a proxy for internet connections (used for subtitle
    downloading)
* Thu Nov 13 2008 guru@unixtech.be
- added Authors to description
- update to 0.6.5.1:
  * subtitles when using the SSA/ASS library can now be further customized:
    it's possible to select the font, size, colors, bold, italic, outline,
    shadow...
  * now tries to follow the XDG Base Directory Specification for the config
    files: that means the now the configuration files will be saved under the
    directory $XDG_CONFIG_HOME/smplayer (or $HOME/.config/smplayer if
    $XDG_CONFIG_HOME is not defined); if you want to keep your preferences,
    copy or move the files from $HOME/.smplayer to the new location
  * adds some options in Preferences->Interface to configure the floating
    control
  * the commandline option -ini-path has been removed and replaced with
  - config-path, which specifies the directory where smplayer will store its
    data (not only smplayer.ini)
* Sat Oct 25 2008 guru@unixtech.be
- removed old %%%%changelog entries
- update to 0.6.4:
  * the dialog to find subtitles can also download the subtitle file and load it in smplayer automatically
  * the black screen problem when using Compiz should really be fixed now
  * added support for encoding autodetection for subtitle files (requires a mplayer compiled with enca support)
  * now it's possible to choose the audio device to be used with alsa (needs the application "aplay")
  * added the possibility to add consecutive files (video_01.avi, video_02.avi..) automatically to the playlist
  * bugfix: logout is not cancelled by smplayer
  * now the options in preferences display a tooltip with a help message
  * now it's possible to change the video track
  * added the Galician translation
* Fri Sep 26 2008 guru@unixtech.be
- update to 0.6.3:
  * added a fix for a black screen problem when using Compiz
  * added an option to select the number of threads that mplayer will use for
    decoding (only works for MPEG-1/2 and some H.264 videos)
  * added the possibility to disable the audio equalizer; seems to be
    necessary to use the S/PDIF output
  * added some options to increase/decrease the speed by 1%%%% and 4%%%%; this
    allows to play 24 fps movies at 25 fps speed and vice versa
  * fix: sometimes the playlist is not shown; added a workaround for the problem
  * added some checks to avoid crashes when selecting subtitle tracks
  * the settings in smplayer.ini have been reorganized in several sections
    (this also means most of your preferences will be lost and you will have
    to reconfigure smplayer again)
  * added an option to mirror the video, and now it's also possible to flip
    and rotate the subtitles along with the image
  * added a new shortcut set (sda.keys) which can be loaded in the shortcut
    editor in preferences
  * added two new translations: Arabic and Kurdish
* Fri Aug 15 2008 guru@unixtech.be
- new upstream version:
  * added an audio equalizer (please read Audio_equalizer.txt)
  * added a dialog to search and download subtitles from opensubtitles.org
    (see Finding_subtitles.txt)
  * the toolbars can be configured: the user can remove, add or change the
    order of the buttons; right now it can only be done by editing manually
    the configuration file, but a graphical editor will be added in the next
    version (see Configuring_the_toolbars.txt)
  * the single instance port can now be chosen automatically by the
    application
  * added a Slovenian translation
* Fri May 30 2008 guru@unixtech.be
- new upstream version:
  * now compact mode resizes the window, instead of leaving black borders
  * added an option in Preferences->Interface which allows the user to select
    his/her preferred GUI; this way it's easier to use the mini GUI, for those
    who prefer a simpler interface with few buttons
  * one more fix for Qt 4.4: the option FAQ in the Help menu didn't work
  * added the Catalan translation
* Wed May 14 2008 guru@unixtech.be
- promoting smplayer-beta to smplayer
* Tue May 13 2008 guru@unixtech.be
- new upstream version
